@@ -11,13 +11,13 @@ import sys
 
 import cvdast.CloudvectorDAST
 import shutil
-from cvdastwrapper import runonetest
-from cvdastwrapper import runconfig
-from cvdastwrapper.runconfig import inspecdir
-from cvdastwrapper.runconfig import dlogrespdname
-from cvdastwrapper.runconfig import dloginputdname
-from cvdastwrapper.runconfig import apispeclist, fuzzattacklist
-from cvdastwrapper.html_content_gen import generate_test_report
+import runonetest
+import runconfig
+from runconfig import inspecdir
+from runconfig import dlogrespdname
+from runconfig import dloginputdname
+from runconfig import apispeclist, fuzzattacklist
+from html_content_gen import generate_test_report
 from jinja2 import Environment, FileSystemLoader
 import reportutil
 
@@ -368,14 +368,15 @@ def iterateallspecs(inspeclist=[], inattacklist=[]):
 
 
 def get_most_frequent_attack(report_json):
-    res = {
-        "attack": "",
-        "count": 0,
-        "nu_of_apis": 0
-    }
-    for spec in runconfig.apispeclist:
-        spec_report = report_json.get(spec, {})
-    return res
+    attack_category_json = report_json['attack_category']
+    sorted(attack_category_json.items(), key=lambda item: 'count')
+    res = list(attack_category_json.keys())[0]
+    val = attack_category_json[res]
+    freq_string = res + " - " + str(val['count']) + \
+        " Tests Failed Across " + \
+        str(len(val['p1_apis']) + len(val['p2_apis']) +
+            len(val['p3_apis']) + len(val['p4_apis'])) + " APIs."
+    return freq_string
 
 
 def get_attack_catogery_count(report_json):
@@ -435,7 +436,7 @@ def generate_html_report(result_report_json, filename):
     # print(templates_dir, root) - root is project root directory that is report_gen
     template = env.get_template('index.html')
 
-    #frequent_attack = get_most_frequent_attack(result_report_json)
+    frequent_attack = get_most_frequent_attack(result_report_json)
     category_counts = get_attack_catogery_count(result_report_json)
     spec_details = get_spec_details(result_report_json)
 
@@ -467,7 +468,8 @@ def generate_html_report(result_report_json, filename):
 
             attack_category=category_counts,
 
-            spec_details=spec_details
+            spec_details=spec_details,
+            frequent_attack=frequent_attack
         ))
 
     return
@@ -493,7 +495,7 @@ def main():
     print("*****" * 20)
 
     reportutil.init()
-    result_report = iterateallspecs(apispeclist, runconfig.fuzzattacklist)
+    result_report = iterateallspecs(apispeclist, runconfig.fuzzattacklist)    
     generate_html_report(result_report, "sample.html")
 
 
