@@ -10,12 +10,12 @@ import sys
 
 import cvdast.CloudvectorDAST
 import shutil
-import runonetest
-import runconfig
-from runconfig import inspecdir
-from runconfig import dlogrespdname
-from runconfig import dloginputdname
-import reportutil
+from cvdastwrapper import runonetest
+from cvdastwrapper import runconfig
+from cvdastwrapper.runconfig import inspecdir
+from cvdastwrapper.runconfig import dlogrespdname
+from cvdastwrapper.runconfig import dloginputdname
+from cvdastwrapper import reportutil
 
 
 resultrootn = runconfig.dresultdir + "/" + runconfig.dperadir + "/"
